@@ -9,6 +9,9 @@ __BEGIN_DECLS
 int set_signal_handler(int sig, void (*handler)(int));
 
 void error(const char* format, ...);
+
+//	If 'cond', print an error message and exit.
+//	Acts like perror() if 'format' doesn't end with "\n".
 void die_if(int cond, const char* format, ...);
 
 char* itoa(int x);
@@ -28,6 +31,8 @@ __END_DECLS
 
 #include <string>
 
+std::string itos(int x);
+
 // Return the string for "path1/path2"
 std::string mkfilename(const std::string& path1, const std::string& path2);
 
