@@ -2,6 +2,7 @@
 #define MSWATCH_CONFIG_H
 
 #include <map>
+#include <set>
 #include <string>
 
 #include <time.h>
@@ -9,6 +10,7 @@
 #include "mailstore_watcher.h"
 
 using std::map;
+using std::set;
 using std::string;
 
 #define NWATCHERS 2
@@ -25,6 +27,8 @@ class mswatch_config
 	time_t default_inter_delay;
 	map<string, time_t> inter_delays; // mailbox_name->delay
 	time_t max_delay;
+	time_t poll_period;
+	set<string> ignores;
 	char** sync_bin;
 	char* mailbox_prefix[2];
 	unsigned sync_bin_len;
