@@ -1,24 +1,23 @@
-/* A Bison parser, made by GNU Bison 2.3.  */
+
+/* A Bison parser, made by GNU Bison 2.4.1.  */
 
 /* Skeleton implementation for Bison's Yacc-like parsers in C
-
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
+   
+      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
    Free Software Foundation, Inc.
-
-   This program is free software; you can redistribute it and/or modify
+   
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
-
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+   
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-
+   
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 /* As a special exception, you may create a larger work that contains
    part or all of the Bison parser skeleton and distribute that work
@@ -29,7 +28,7 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-
+   
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
@@ -47,7 +46,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "2.3"
+#define YYBISON_VERSION "2.4.1"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -55,57 +54,30 @@
 /* Pure parsers.  */
 #define YYPURE 0
 
+/* Push parsers.  */
+#define YYPUSH 0
+
+/* Pull parsers.  */
+#define YYPULL 1
+
 /* Using locations.  */
 #define YYLSP_NEEDED 0
 
 
 
-/* Tokens.  */
-#ifndef YYTOKENTYPE
-# define YYTOKENTYPE
-   /* Put the tokens into the symbol table, so that GDB and other debuggers
-      know about them.  */
-   enum yytokentype {
-     TEXT = 258,
-     NUM = 259,
-     BASEDELAY = 260,
-     INTERDELAY = 261,
-     MAXDELAY = 262,
-     SYNC = 263,
-     MAILBOXPREFIX = 264,
-     STORE = 265,
-     WATCH = 266,
-     CBOPEN = 267,
-     CBCLOSE = 268,
-     EOL = 269
-   };
-#endif
-/* Tokens.  */
-#define TEXT 258
-#define NUM 259
-#define BASEDELAY 260
-#define INTERDELAY 261
-#define MAXDELAY 262
-#define SYNC 263
-#define MAILBOXPREFIX 264
-#define STORE 265
-#define WATCH 266
-#define CBOPEN 267
-#define CBCLOSE 268
-#define EOL 269
-
-
-
-
 /* Copy the first part of user declarations.  */
+
+/* Line 189 of yacc.c  */
 #line 1 "parser.y"
 
 /* mswatch configuration parser */
 
 /* TODO:
  * - add error reporting
- * - don't make base_delay, inter_delay, max_delay, sync, store, and watch keywords?
+ * - don't make base_delay, inter_delay, max_delay, poll_period, sync, store, and watch keywords?
  */
+
+/* Line 189 of yacc.c  */
 #line 10 "parser.y"
 
 #include <stdio.h>
@@ -136,6 +108,9 @@ int yywrap(void)
 }
 
 
+/* Line 189 of yacc.c  */
+#line 113 "parser.c"
+
 /* Enabling traces.  */
 #ifndef YYDEBUG
 # define YYDEBUG 0
@@ -154,31 +129,77 @@ int yywrap(void)
 # define YYTOKEN_TABLE 0
 #endif
 
+
+/* Tokens.  */
+#ifndef YYTOKENTYPE
+# define YYTOKENTYPE
+   /* Put the tokens into the symbol table, so that GDB and other debuggers
+      know about them.  */
+   enum yytokentype {
+     TEXT = 258,
+     NUM = 259,
+     BASEDELAY = 260,
+     INTERDELAY = 261,
+     MAXDELAY = 262,
+     POLLPERIOD = 263,
+     IGNORE = 264,
+     SYNC = 265,
+     MAILBOXPREFIX = 266,
+     STORE = 267,
+     WATCH = 268,
+     CBOPEN = 269,
+     CBCLOSE = 270,
+     EOL = 271
+   };
+#endif
+/* Tokens.  */
+#define TEXT 258
+#define NUM 259
+#define BASEDELAY 260
+#define INTERDELAY 261
+#define MAXDELAY 262
+#define POLLPERIOD 263
+#define IGNORE 264
+#define SYNC 265
+#define MAILBOXPREFIX 266
+#define STORE 267
+#define WATCH 268
+#define CBOPEN 269
+#define CBCLOSE 270
+#define EOL 271
+
+
+
+
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 40 "parser.y"
 {
+
+/* Line 214 of yacc.c  */
+#line 40 "parser.y"
+
 	int num;
 	char* str;
 	struct rc_setting* setting;
 	struct rc_store_setting* store_setting;
 	struct str_list* str_list;
-}
-/* Line 187 of yacc.c.  */
-#line 169 "parser.c"
-	YYSTYPE;
+
+
+
+/* Line 214 of yacc.c  */
+#line 191 "parser.c"
+} YYSTYPE;
+# define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
-# define YYSTYPE_IS_TRIVIAL 1
 #endif
 
 
-
 /* Copy the second part of user declarations.  */
 
 
-/* Line 216 of yacc.c.  */
-#line 182 "parser.c"
+/* Line 264 of yacc.c  */
+#line 203 "parser.c"
 
 #ifdef short
 # undef short
@@ -253,14 +274,14 @@ typedef short int yytype_int16;
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static int
-YYID (int i)
+YYID (int yyi)
 #else
 static int
-YYID (i)
-    int i;
+YYID (yyi)
+    int yyi;
 #endif
 {
-  return i;
+  return yyi;
 }
 #endif
 
@@ -341,9 +362,9 @@ void free (void *); /* INFRINGES ON USER NAME SPACE */
 /* A type that is properly aligned for any stack member.  */
 union yyalloc
 {
-  yytype_int16 yyss;
-  YYSTYPE yyvs;
-  };
+  yytype_int16 yyss_alloc;
+  YYSTYPE yyvs_alloc;
+};
 
 /* The size of the maximum gap between one aligned stack and the next.  */
 # define YYSTACK_GAP_MAXIMUM (sizeof (union yyalloc) - 1)
@@ -377,12 +398,12 @@ union yyalloc
    elements in the stack, and YYPTR gives the new location of the
    stack.  Advance YYPTR to a properly aligned location for the next
    stack.  */
-# define YYSTACK_RELOCATE(Stack)					\
+# define YYSTACK_RELOCATE(Stack_alloc, Stack)				\
     do									\
       {									\
 	YYSIZE_T yynewbytes;						\
-	YYCOPY (&yyptr->Stack, Stack, yysize);				\
-	Stack = &yyptr->Stack;						\
+	YYCOPY (&yyptr->Stack_alloc, Stack, yysize);			\
+	Stack = &yyptr->Stack_alloc;					\
 	yynewbytes = yystacksize * sizeof (*Stack) + YYSTACK_GAP_MAXIMUM; \
 	yyptr += yynewbytes / sizeof (*yyptr);				\
       }									\
@@ -391,22 +412,22 @@ union yyalloc
 #endif
 
 /* YYFINAL -- State number of the termination state.  */
-#define YYFINAL  22
+#define YYFINAL  26
 /* YYLAST -- Last index in YYTABLE.  */
-#define YYLAST   41
+#define YYLAST   59
 
 /* YYNTOKENS -- Number of terminals.  */
-#define YYNTOKENS  15
+#define YYNTOKENS  17
 /* YYNNTS -- Number of nonterminals.  */
 #define YYNNTS  11
 /* YYNRULES -- Number of rules.  */
-#define YYNRULES  24
+#define YYNRULES  26
 /* YYNRULES -- Number of states.  */
-#define YYNSTATES  42
+#define YYNSTATES  46
 
 /* YYTRANSLATE(YYLEX) -- Bison symbol number corresponding to YYLEX.  */
 #define YYUNDEFTOK  2
-#define YYMAXUTOK   269
+#define YYMAXUTOK   271
 
 #define YYTRANSLATE(YYX)						\
   ((unsigned int) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)
@@ -440,7 +461,8 @@ static const yytype_uint8 yytranslate[] =
        2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
        2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
        2,     2,     2,     2,     2,     2,     1,     2,     3,     4,
-       5,     6,     7,     8,     9,    10,    11,    12,    13,    14
+       5,     6,     7,     8,     9,    10,    11,    12,    13,    14,
+      15,    16
 };
 
 #if YYDEBUG
@@ -449,29 +471,29 @@ static const yytype_uint8 yytranslate[] =
 static const yytype_uint8 yyprhs[] =
 {
        0,     0,     3,     5,     7,    10,    14,    17,    20,    24,
-      27,    30,    34,    43,    45,    49,    52,    54,    57,    59,
-      61,    63,    64,    66,    68
+      27,    30,    33,    36,    40,    49,    51,    55,    58,    60,
+      63,    65,    67,    69,    70,    72,    74
 };
 
 /* YYRHS -- A `-1'-separated list of the rules' RHS.  */
 static const yytype_int8 yyrhs[] =
 {
-      16,     0,    -1,    17,    -1,    25,    -1,    18,    25,    -1,
-      17,    18,    25,    -1,     5,     4,    -1,     6,     4,    -1,
-       6,     4,    21,    -1,     7,     4,    -1,     8,    21,    -1,
-       9,    23,    23,    -1,    10,     3,    24,    12,    24,    19,
-      24,    13,    -1,    20,    -1,    19,    25,    20,    -1,    11,
-      21,    -1,    22,    -1,    21,    22,    -1,    23,    -1,     3,
-      -1,     4,    -1,    -1,    25,    -1,    14,    -1,    25,    14,
-      -1
+      18,     0,    -1,    19,    -1,    27,    -1,    20,    27,    -1,
+      19,    20,    27,    -1,     5,     4,    -1,     6,     4,    -1,
+       6,     4,    23,    -1,     7,     4,    -1,     8,     4,    -1,
+       9,    23,    -1,    10,    23,    -1,    11,    25,    25,    -1,
+      12,     3,    26,    14,    26,    21,    26,    15,    -1,    22,
+      -1,    21,    27,    22,    -1,    13,    23,    -1,    24,    -1,
+      23,    24,    -1,    25,    -1,     3,    -1,     4,    -1,    -1,
+      27,    -1,    16,    -1,    27,    16,    -1
 };
 
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const yytype_uint8 yyrline[] =
 {
        0,    63,    63,    67,    69,    71,    75,    77,    79,    81,
-      83,    85,    87,    91,    93,    97,   101,   103,   107,   111,
-     113,   117,   118,   121,   122
+      83,    85,    87,    89,    91,    95,    97,   101,   105,   107,
+     111,   115,   117,   121,   122,   125,   126
 };
 #endif
 
@@ -481,10 +503,10 @@ static const yytype_uint8 yyrline[] =
 static const char *const yytname[] =
 {
   "$end", "error", "$undefined", "TEXT", "NUM", "BASEDELAY", "INTERDELAY",
-  "MAXDELAY", "SYNC", "MAILBOXPREFIX", "STORE", "WATCH", "CBOPEN",
-  "CBCLOSE", "EOL", "$accept", "config", "settings", "setting",
-  "store_settings", "store_setting", "strings", "string", "text",
-  "opt_eols", "eols", 0
+  "MAXDELAY", "POLLPERIOD", "IGNORE", "SYNC", "MAILBOXPREFIX", "STORE",
+  "WATCH", "CBOPEN", "CBCLOSE", "EOL", "$accept", "config", "settings",
+  "setting", "store_settings", "store_setting", "strings", "string",
+  "text", "opt_eols", "eols", 0
 };
 #endif
 
@@ -494,24 +516,24 @@ static const char *const yytname[] =
 static const yytype_uint16 yytoknum[] =
 {
        0,   256,   257,   258,   259,   260,   261,   262,   263,   264,
-     265,   266,   267,   268,   269
+     265,   266,   267,   268,   269,   270,   271
 };
 # endif
 
 /* YYR1[YYN] -- Symbol number of symbol that rule YYN derives.  */
 static const yytype_uint8 yyr1[] =
 {
-       0,    15,    16,    17,    17,    17,    18,    18,    18,    18,
-      18,    18,    18,    19,    19,    20,    21,    21,    22,    23,
-      23,    24,    24,    25,    25
+       0,    17,    18,    19,    19,    19,    20,    20,    20,    20,
+      20,    20,    20,    20,    20,    21,    21,    22,    23,    23,
+      24,    25,    25,    26,    26,    27,    27
 };
 
 /* YYR2[YYN] -- Number of symbols composing right hand side of rule YYN.  */
 static const yytype_uint8 yyr2[] =
 {
        0,     2,     1,     1,     2,     3,     2,     2,     3,     2,
-       2,     3,     8,     1,     3,     2,     1,     2,     1,     1,
-       1,     0,     1,     1,     2
+       2,     2,     2,     3,     8,     1,     3,     2,     1,     2,
+       1,     1,     1,     0,     1,     1,     2
 };
 
 /* YYDEFACT[STATE-NAME] -- Default rule to reduce with in state
@@ -519,36 +541,36 @@ static const yytype_uint8 yyr2[] =
    means the default is an error.  */
 static const yytype_uint8 yydefact[] =
 {
-       0,     0,     0,     0,     0,     0,     0,    23,     0,     2,
-       0,     3,     6,     7,     9,    19,    20,    10,    16,    18,
-       0,    21,     1,     0,     4,    24,     8,    17,    11,     0,
-      22,     5,    21,     0,     0,    21,    13,    15,     0,    22,
-      12,    14
+       0,     0,     0,     0,     0,     0,     0,     0,     0,    25,
+       0,     2,     0,     3,     6,     7,     9,    10,    21,    22,
+      11,    18,    20,    12,     0,    23,     1,     0,     4,    26,
+       8,    19,    13,     0,    24,     5,    23,     0,     0,    23,
+      15,    17,     0,    24,    14,    16
 };
 
 /* YYDEFGOTO[NTERM-NUM].  */
 static const yytype_int8 yydefgoto[] =
 {
-      -1,     8,     9,    10,    35,    36,    17,    18,    19,    29,
-      30
+      -1,    10,    11,    12,    39,    40,    20,    21,    22,    33,
+      34
 };
 
 /* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
    STATE-NUM.  */
-#define YYPACT_NINF -28
+#define YYPACT_NINF -29
 static const yytype_int8 yypact[] =
 {
-      20,     3,     5,    10,     8,     8,    12,   -28,    16,    31,
-       4,     6,   -28,     8,   -28,   -28,   -28,     8,   -28,   -28,
-       8,     4,   -28,     4,     6,   -28,     8,   -28,   -28,     7,
-       6,     6,     4,    21,     8,     4,   -28,     8,    18,    -8,
-     -28,   -28
+      35,     3,     5,    12,    13,    11,    11,    11,    15,   -29,
+      19,    47,     4,     6,   -29,    11,   -29,   -29,   -29,   -29,
+      11,   -29,   -29,    11,    11,     4,   -29,     4,     6,   -29,
+      11,   -29,   -29,     9,     6,     6,     4,    16,    11,     4,
+     -29,    11,    10,   -11,   -29,   -29
 };
 
 /* YYPGOTO[NTERM-NUM].  */
 static const yytype_int8 yypgoto[] =
 {
-     -28,   -28,   -28,    24,   -28,   -18,   -12,   -13,    -3,   -27,
+     -29,   -29,   -29,    17,   -29,   -13,    -5,   -17,    -3,   -28,
        0
 };
 
@@ -559,31 +581,33 @@ static const yytype_int8 yypgoto[] =
 #define YYTABLE_NINF -1
 static const yytype_uint8 yytable[] =
 {
-      11,    26,    20,    34,    27,    33,    25,    12,    38,    13,
-      24,    15,    16,    27,    14,    21,    22,    28,     7,    32,
-      25,    41,    37,    31,    27,     1,     2,     3,     4,     5,
-       6,    40,    34,    23,     7,    39,     1,     2,     3,     4,
-       5,     6
+      13,    23,    38,    31,    24,    29,    31,    14,    37,    15,
+      30,    42,    28,    31,    18,    19,    16,    17,    25,    26,
+       9,    32,    29,    36,    31,    44,     0,    35,    27,    38,
+      45,     0,     0,    41,     0,     0,     0,     0,     0,    43,
+       1,     2,     3,     4,     5,     6,     7,     8,     0,     0,
+       0,     9,     1,     2,     3,     4,     5,     6,     7,     8
 };
 
-static const yytype_uint8 yycheck[] =
+static const yytype_int8 yycheck[] =
 {
-       0,    13,     5,    11,    17,    32,    14,     4,    35,     4,
-      10,     3,     4,    26,     4,     3,     0,    20,    14,    12,
-      14,    39,    34,    23,    37,     5,     6,     7,     8,     9,
-      10,    13,    11,     9,    14,    35,     5,     6,     7,     8,
-       9,    10
+       0,     6,    13,    20,     7,    16,    23,     4,    36,     4,
+      15,    39,    12,    30,     3,     4,     4,     4,     3,     0,
+      16,    24,    16,    14,    41,    15,    -1,    27,    11,    13,
+      43,    -1,    -1,    38,    -1,    -1,    -1,    -1,    -1,    39,
+       5,     6,     7,     8,     9,    10,    11,    12,    -1,    -1,
+      -1,    16,     5,     6,     7,     8,     9,    10,    11,    12
 };
 
 /* YYSTOS[STATE-NUM] -- The (internal number of the) accessing
    symbol of state STATE-NUM.  */
 static const yytype_uint8 yystos[] =
 {
-       0,     5,     6,     7,     8,     9,    10,    14,    16,    17,
-      18,    25,     4,     4,     4,     3,     4,    21,    22,    23,
-      23,     3,     0,    18,    25,    14,    21,    22,    23,    24,
-      25,    25,    12,    24,    11,    19,    20,    21,    24,    25,
-      13,    20
+       0,     5,     6,     7,     8,     9,    10,    11,    12,    16,
+      18,    19,    20,    27,     4,     4,     4,     4,     3,     4,
+      23,    24,    25,    23,    25,     3,     0,    20,    27,    16,
+      23,    24,    25,    26,    27,    27,    14,    26,    13,    21,
+      22,    23,    26,    27,    15,    22
 };
 
 #define yyerrok		(yyerrstatus = 0)
@@ -768,17 +792,20 @@ yy_symbol_print (yyoutput, yytype, yyvaluep)
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static void
-yy_stack_print (yytype_int16 *bottom, yytype_int16 *top)
+yy_stack_print (yytype_int16 *yybottom, yytype_int16 *yytop)
 #else
 static void
-yy_stack_print (bottom, top)
-    yytype_int16 *bottom;
-    yytype_int16 *top;
+yy_stack_print (yybottom, yytop)
+    yytype_int16 *yybottom;
+    yytype_int16 *yytop;
 #endif
 {
   YYFPRINTF (stderr, "Stack now");
-  for (; bottom <= top; ++bottom)
-    YYFPRINTF (stderr, " %d", *bottom);
+  for (; yybottom <= yytop; yybottom++)
+    {
+      int yybot = *yybottom;
+      YYFPRINTF (stderr, " %d", yybot);
+    }
   YYFPRINTF (stderr, "\n");
 }
 
@@ -812,11 +839,11 @@ yy_reduce_print (yyvsp, yyrule)
   /* The symbols being reduced.  */
   for (yyi = 0; yyi < yynrhs; yyi++)
     {
-      fprintf (stderr, "   $%d = ", yyi + 1);
+      YYFPRINTF (stderr, "   $%d = ", yyi + 1);
       yy_symbol_print (stderr, yyrhs[yyprhs[yyrule] + yyi],
 		       &(yyvsp[(yyi + 1) - (yynrhs)])
 		       		       );
-      fprintf (stderr, "\n");
+      YYFPRINTF (stderr, "\n");
     }
 }
 
@@ -1096,10 +1123,8 @@ yydestruct (yymsg, yytype, yyvaluep)
 	break;
     }
 }
-
 
 /* Prevent warnings from -Wmissing-prototypes.  */
-
 #ifdef YYPARSE_PARAM
 #if defined __STDC__ || defined __cplusplus
 int yyparse (void *YYPARSE_PARAM);
@@ -1115,11 +1140,10 @@ int yyparse ();
 #endif /* ! YYPARSE_PARAM */
 
 
-
-/* The look-ahead symbol.  */
+/* The lookahead symbol.  */
 int yychar;
 
-/* The semantic value of the look-ahead symbol.  */
+/* The semantic value of the lookahead symbol.  */
 YYSTYPE yylval;
 
 /* Number of syntax errors so far.  */
@@ -1127,9 +1151,9 @@ int yynerrs;
 
 
 
-/*----------.
-| yyparse.  |
-`----------*/
+/*-------------------------.
+| yyparse or yypush_parse.  |
+`-------------------------*/
 
 #ifdef YYPARSE_PARAM
 #if (defined __STDC__ || defined __C99__FUNC__ \
@@ -1153,14 +1177,39 @@ yyparse ()
 #endif
 #endif
 {
-  
-  int yystate;
+
+
+    int yystate;
+    /* Number of tokens to shift before error messages enabled.  */
+    int yyerrstatus;
+
+    /* The stacks and their tools:
+       `yyss': related to states.
+       `yyvs': related to semantic values.
+
+       Refer to the stacks thru separate pointers, to allow yyoverflow
+       to reallocate them elsewhere.  */
+
+    /* The state stack.  */
+    yytype_int16 yyssa[YYINITDEPTH];
+    yytype_int16 *yyss;
+    yytype_int16 *yyssp;
+
+    /* The semantic value stack.  */
+    YYSTYPE yyvsa[YYINITDEPTH];
+    YYSTYPE *yyvs;
+    YYSTYPE *yyvsp;
+
+    YYSIZE_T yystacksize;
+
   int yyn;
   int yyresult;
-  /* Number of tokens to shift before error messages enabled.  */
-  int yyerrstatus;
-  /* Look-ahead token as an internal (translated) token number.  */
-  int yytoken = 0;
+  /* Lookahead token as an internal (translated) token number.  */
+  int yytoken;
+  /* The variables used to return semantic value and location from the
+     action routines.  */
+  YYSTYPE yyval;
+
 #if YYERROR_VERBOSE
   /* Buffer for error messages, and its allocated size.  */
   char yymsgbuf[128];
@@ -1168,51 +1217,28 @@ yyparse ()
   YYSIZE_T yymsg_alloc = sizeof yymsgbuf;
 #endif
 
-  /* Three stacks and their tools:
-     `yyss': related to states,
-     `yyvs': related to semantic values,
-     `yyls': related to locations.
-
-     Refer to the stacks thru separate pointers, to allow yyoverflow
-     to reallocate them elsewhere.  */
-
-  /* The state stack.  */
-  yytype_int16 yyssa[YYINITDEPTH];
-  yytype_int16 *yyss = yyssa;
-  yytype_int16 *yyssp;
-
-  /* The semantic value stack.  */
-  YYSTYPE yyvsa[YYINITDEPTH];
-  YYSTYPE *yyvs = yyvsa;
-  YYSTYPE *yyvsp;
-
-
-
 #define YYPOPSTACK(N)   (yyvsp -= (N), yyssp -= (N))
 
-  YYSIZE_T yystacksize = YYINITDEPTH;
-
-  /* The variables used to return semantic value and location from the
-     action routines.  */
-  YYSTYPE yyval;
-
-
   /* The number of symbols on the RHS of the reduced rule.
      Keep to zero when no symbol should be popped.  */
   int yylen = 0;
 
+  yytoken = 0;
+  yyss = yyssa;
+  yyvs = yyvsa;
+  yystacksize = YYINITDEPTH;
+
   YYDPRINTF ((stderr, "Starting parse\n"));
 
   yystate = 0;
   yyerrstatus = 0;
   yynerrs = 0;
-  yychar = YYEMPTY;		/* Cause a token to be read.  */
+  yychar = YYEMPTY; /* Cause a token to be read.  */
 
   /* Initialize stack pointers.
      Waste one element of value and location stack
      so that they stay on the same level as the state stack.
      The wasted elements are never initialized.  */
-
   yyssp = yyss;
   yyvsp = yyvs;
 
@@ -1242,7 +1268,6 @@ yyparse ()
 	YYSTYPE *yyvs1 = yyvs;
 	yytype_int16 *yyss1 = yyss;
 
-
 	/* Each stack pointer address is followed by the size of the
 	   data in use in that stack, in bytes.  This used to be a
 	   conditional around just the two extra args, but that might
@@ -1250,7 +1275,6 @@ yyparse ()
 	yyoverflow (YY_("memory exhausted"),
 		    &yyss1, yysize * sizeof (*yyssp),
 		    &yyvs1, yysize * sizeof (*yyvsp),
-
 		    &yystacksize);
 
 	yyss = yyss1;
@@ -1273,9 +1297,8 @@ yyparse ()
 	  (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
 	if (! yyptr)
 	  goto yyexhaustedlab;
-	YYSTACK_RELOCATE (yyss);
-	YYSTACK_RELOCATE (yyvs);
-
+	YYSTACK_RELOCATE (yyss_alloc, yyss);
+	YYSTACK_RELOCATE (yyvs_alloc, yyvs);
 #  undef YYSTACK_RELOCATE
 	if (yyss1 != yyssa)
 	  YYSTACK_FREE (yyss1);
@@ -1286,7 +1309,6 @@ yyparse ()
       yyssp = yyss + yysize - 1;
       yyvsp = yyvs + yysize - 1;
 
-
       YYDPRINTF ((stderr, "Stack size increased to %lu\n",
 		  (unsigned long int) yystacksize));
 
@@ -1296,6 +1318,9 @@ yyparse ()
 
   YYDPRINTF ((stderr, "Entering state %d\n", yystate));
 
+  if (yystate == YYFINAL)
+    YYACCEPT;
+
   goto yybackup;
 
 /*-----------.
@@ -1304,16 +1329,16 @@ yyparse ()
 yybackup:
 
   /* Do appropriate processing given the current state.  Read a
-     look-ahead token if we need one and don't already have one.  */
+     lookahead token if we need one and don't already have one.  */
 
-  /* First try to decide what to do without reference to look-ahead token.  */
+  /* First try to decide what to do without reference to lookahead token.  */
   yyn = yypact[yystate];
   if (yyn == YYPACT_NINF)
     goto yydefault;
 
-  /* Not known => get a look-ahead token if don't already have one.  */
+  /* Not known => get a lookahead token if don't already have one.  */
 
-  /* YYCHAR is either YYEMPTY or YYEOF or a valid look-ahead symbol.  */
+  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
   if (yychar == YYEMPTY)
     {
       YYDPRINTF ((stderr, "Reading a token: "));
@@ -1345,20 +1370,16 @@ yybackup:
       goto yyreduce;
     }
 
-  if (yyn == YYFINAL)
-    YYACCEPT;
-
   /* Count tokens shifted since error; after three, turn off error
      status.  */
   if (yyerrstatus)
     yyerrstatus--;
 
-  /* Shift the look-ahead token.  */
+  /* Shift the lookahead token.  */
   YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);
 
-  /* Discard the shifted token unless it is eof.  */
-  if (yychar != YYEOF)
-    yychar = YYEMPTY;
+  /* Discard the shifted token.  */
+  yychar = YYEMPTY;
 
   yystate = yyn;
   *++yyvsp = yylval;
@@ -1398,123 +1419,184 @@ yyreduce:
   switch (yyn)
     {
         case 2:
+
+/* Line 1455 of yacc.c  */
 #line 64 "parser.y"
     { (yyval.setting) = NULL; emit((yyvsp[(1) - (1)].setting)); }
     break;
 
   case 3:
+
+/* Line 1455 of yacc.c  */
 #line 68 "parser.y"
     { (yyval.setting) = NULL; }
     break;
 
   case 4:
+
+/* Line 1455 of yacc.c  */
 #line 70 "parser.y"
     { (yyval.setting) = (yyvsp[(1) - (2)].setting); }
     break;
 
   case 5:
+
+/* Line 1455 of yacc.c  */
 #line 72 "parser.y"
     { (yyval.setting) = append_rc((yyvsp[(1) - (3)].setting), (yyvsp[(2) - (3)].setting)); }
     break;
 
   case 6:
+
+/* Line 1455 of yacc.c  */
 #line 76 "parser.y"
     { (yyval.setting) = create_base_delay((yyvsp[(2) - (2)].num)); }
     break;
 
   case 7:
+
+/* Line 1455 of yacc.c  */
 #line 78 "parser.y"
     { (yyval.setting) = create_inter_delay((yyvsp[(2) - (2)].num)); }
     break;
 
   case 8:
+
+/* Line 1455 of yacc.c  */
 #line 80 "parser.y"
     { (yyval.setting) = create_inter_delay_list((yyvsp[(2) - (3)].num), (yyvsp[(3) - (3)].str_list)); }
     break;
 
   case 9:
+
+/* Line 1455 of yacc.c  */
 #line 82 "parser.y"
     { (yyval.setting) = create_max_delay((yyvsp[(2) - (2)].num)); }
     break;
 
   case 10:
+
+/* Line 1455 of yacc.c  */
 #line 84 "parser.y"
-    { (yyval.setting) = create_sync((yyvsp[(2) - (2)].str_list)); }
+    { (yyval.setting) = create_poll_period((yyvsp[(2) - (2)].num)); }
     break;
 
   case 11:
+
+/* Line 1455 of yacc.c  */
 #line 86 "parser.y"
-    { (yyval.setting) = create_mailbox_prefix((yyvsp[(2) - (3)].str), (yyvsp[(3) - (3)].str)); }
+    { (yyval.setting) = create_ignore((yyvsp[(2) - (2)].str_list)); }
     break;
 
   case 12:
+
+/* Line 1455 of yacc.c  */
 #line 88 "parser.y"
-    { (yyval.setting) = create_store(append_rc_store(create_store_name((yyvsp[(2) - (8)].str)), (yyvsp[(6) - (8)].store_setting))); }
+    { (yyval.setting) = create_sync((yyvsp[(2) - (2)].str_list)); }
     break;
 
   case 13:
-#line 92 "parser.y"
-    { (yyval.store_setting) = (yyvsp[(1) - (1)].store_setting); }
+
+/* Line 1455 of yacc.c  */
+#line 90 "parser.y"
+    { (yyval.setting) = create_mailbox_prefix((yyvsp[(2) - (3)].str), (yyvsp[(3) - (3)].str)); }
     break;
 
   case 14:
-#line 94 "parser.y"
-    { (yyval.store_setting) = append_rc_store((yyvsp[(1) - (3)].store_setting), (yyvsp[(3) - (3)].store_setting)); }
+
+/* Line 1455 of yacc.c  */
+#line 92 "parser.y"
+    { (yyval.setting) = create_store(append_rc_store(create_store_name((yyvsp[(2) - (8)].str)), (yyvsp[(6) - (8)].store_setting))); }
     break;
 
   case 15:
-#line 98 "parser.y"
-    { (yyval.store_setting) = create_store_watch((yyvsp[(2) - (2)].str_list)); }
+
+/* Line 1455 of yacc.c  */
+#line 96 "parser.y"
+    { (yyval.store_setting) = (yyvsp[(1) - (1)].store_setting); }
     break;
 
   case 16:
-#line 102 "parser.y"
-    { (yyval.str_list) = (yyvsp[(1) - (1)].str_list); }
+
+/* Line 1455 of yacc.c  */
+#line 98 "parser.y"
+    { (yyval.store_setting) = append_rc_store((yyvsp[(1) - (3)].store_setting), (yyvsp[(3) - (3)].store_setting)); }
     break;
 
   case 17:
-#line 104 "parser.y"
-    { (yyval.str_list) = append_str((yyvsp[(1) - (2)].str_list), (yyvsp[(2) - (2)].str_list)); }
+
+/* Line 1455 of yacc.c  */
+#line 102 "parser.y"
+    { (yyval.store_setting) = create_store_watch((yyvsp[(2) - (2)].str_list)); }
     break;
 
   case 18:
-#line 108 "parser.y"
-    { (yyval.str_list) = create_str((yyvsp[(1) - (1)].str)); }
+
+/* Line 1455 of yacc.c  */
+#line 106 "parser.y"
+    { (yyval.str_list) = (yyvsp[(1) - (1)].str_list); }
     break;
 
   case 19:
-#line 112 "parser.y"
-    { (yyval.str) = (yyvsp[(1) - (1)].str); }
+
+/* Line 1455 of yacc.c  */
+#line 108 "parser.y"
+    { (yyval.str_list) = append_str((yyvsp[(1) - (2)].str_list), (yyvsp[(2) - (2)].str_list)); }
     break;
 
   case 20:
-#line 114 "parser.y"
-    { (yyval.str) = itoa((yyvsp[(1) - (1)].num)); }
+
+/* Line 1455 of yacc.c  */
+#line 112 "parser.y"
+    { (yyval.str_list) = create_str((yyvsp[(1) - (1)].str)); }
     break;
 
   case 21:
-#line 117 "parser.y"
-    { }
+
+/* Line 1455 of yacc.c  */
+#line 116 "parser.y"
+    { (yyval.str) = (yyvsp[(1) - (1)].str); }
     break;
 
   case 22:
+
+/* Line 1455 of yacc.c  */
 #line 118 "parser.y"
-    { }
+    { (yyval.str) = itoa((yyvsp[(1) - (1)].num)); }
     break;
 
   case 23:
+
+/* Line 1455 of yacc.c  */
 #line 121 "parser.y"
     { }
     break;
 
   case 24:
+
+/* Line 1455 of yacc.c  */
 #line 122 "parser.y"
     { }
     break;
 
+  case 25:
 
-/* Line 1267 of yacc.c.  */
-#line 1518 "parser.c"
+/* Line 1455 of yacc.c  */
+#line 125 "parser.y"
+    { }
+    break;
+
+  case 26:
+
+/* Line 1455 of yacc.c  */
+#line 126 "parser.y"
+    { }
+    break;
+
+
+
+/* Line 1455 of yacc.c  */
+#line 1600 "parser.c"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -1525,7 +1607,6 @@ yyreduce:
 
   *++yyvsp = yyval;
 
-
   /* Now `shift' the result of the reduction.  Determine what state
      that goes to, based on the state we popped back to and the rule
      number reduced by.  */
@@ -1590,7 +1671,7 @@ yyerrlab:
 
   if (yyerrstatus == 3)
     {
-      /* If just tried and failed to reuse look-ahead token after an
+      /* If just tried and failed to reuse lookahead token after an
 	 error, discard it.  */
 
       if (yychar <= YYEOF)
@@ -1607,7 +1688,7 @@ yyerrlab:
 	}
     }
 
-  /* Else will try to reuse look-ahead token after shifting the error
+  /* Else will try to reuse lookahead token after shifting the error
      token.  */
   goto yyerrlab1;
 
@@ -1664,9 +1745,6 @@ yyerrlab1:
       YY_STACK_PRINT (yyss, yyssp);
     }
 
-  if (yyn == YYFINAL)
-    YYACCEPT;
-
   *++yyvsp = yylval;
 
 
@@ -1691,7 +1769,7 @@ yyabortlab:
   yyresult = 1;
   goto yyreturn;
 
-#ifndef yyoverflow
+#if !defined(yyoverflow) || YYERROR_VERBOSE
 /*-------------------------------------------------.
 | yyexhaustedlab -- memory exhaustion comes here.  |
 `-------------------------------------------------*/
@@ -1702,7 +1780,7 @@ yyexhaustedlab:
 #endif
 
 yyreturn:
-  if (yychar != YYEOF && yychar != YYEMPTY)
+  if (yychar != YYEMPTY)
      yydestruct ("Cleanup: discarding lookahead",
 		 yytoken, &yylval);
   /* Do not reclaim the symbols of the rule which action triggered
@@ -1728,7 +1806,9 @@ yyreturn:
 }
 
 
-#line 125 "parser.y"
+
+/* Line 1675 of yacc.c  */
+#line 129 "parser.y"
 
 
 //#define DEBUG_PARSER
