@@ -10,9 +10,11 @@ __BEGIN_DECLS
 #define RCS_INTERDELAY      (1 << 2)
 #define RCS_INTERDELAY_LIST (1 << 3)
 #define RCS_MAXDELAY        (1 << 4)
-#define RCS_SYNC            (1 << 5)
-#define RCS_MAILBOXPREFIX   (1 << 6)
-#define RCS_SS              (1 << 7)
+#define RCS_POLLPERIOD      (1 << 5)
+#define RCS_IGNORE          (1 << 6)
+#define RCS_SYNC            (1 << 7)
+#define RCS_MAILBOXPREFIX   (1 << 8)
+#define RCS_SS              (1 << 9)
 
 struct rc_setting
 {
@@ -25,6 +27,8 @@ struct rc_setting
 			struct str_list* mailboxes;
 		} inter_delay_list;
 		int max_delay;
+		int poll_period;
+		struct str_list* ignores;
 		struct str_list* sync;
 		char* mailbox_prefix[2];
 		struct rc_store_setting* store_setting;
