@@ -14,7 +14,9 @@ struct rc_setting* append_rc(struct rc_setting* prev, struct rc_setting* cur);
 struct rc_setting* create_base_delay(int delay);
 struct rc_setting* create_inter_delay(int delay);
 struct rc_setting* create_inter_delay_list(int delay, struct str_list* str);
+struct rc_setting* create_ignore(struct str_list* str);
 struct rc_setting* create_max_delay(int delay);
+struct rc_setting* create_poll_period(int period);
 struct rc_setting* create_sync(struct str_list* str);
 struct rc_setting* create_mailbox_prefix(char* prefix, char* sep);
 struct rc_setting* create_store(struct rc_store_setting* store_setting);
